@@ -27,6 +27,7 @@ import re
 
 import hpccm.config
 import hpccm.templates.CMakeBuild
+import hpccm.templates.envvars
 import hpccm.templates.ldconfig
 import hpccm.templates.rm
 import hpccm.templates.tar
@@ -41,8 +42,9 @@ from hpccm.primitives.environment import environment
 from hpccm.primitives.shell import shell
 from hpccm.toolchain import toolchain
 
-class catalyst(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.ldconfig,
-               hpccm.templates.rm, hpccm.templates.tar, hpccm.templates.wget):
+class catalyst(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.envvars,
+               hpccm.templates.ldconfig, hpccm.templates.rm,
+               hpccm.templates.tar, hpccm.templates.wget):
     """The `catalyst` building block configures, builds, and installs the
     [ParaView Catalyst](https://www.paraview.org/in-situ/) component.
 
@@ -52,9 +54,6 @@ class catalyst(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.ldconfig,
     A MPI building block should be installed prior to this building
     block.
 
-    As a side effect, this building block modifies `PATH` to include
-    the Catalyst build.
-
     If GPU rendering will be used then a
     [cudagl](https://hub.docker.com/r/nvidia/cudagl) base image is
     recommended.
@@ -75,6 +74,10 @@ class catalyst(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.ldconfig,
     building block. The default value is
     `Base-Enable-Python-Essentials-Extras-Rendering-Base`.
 
+    environment: Boolean flag to specify whether the environment
+    (`LD_LIBRARY_PATH` and `PATH`) should be modified to include
+    ParaView Catalyst. The default is True.
+
     ldconfig: Boolean flag to specify whether the Catalyst library
     directory should be added dynamic linker cache.  If False, then
     `LD_LIBRARY_PATH` is modified to include the Catalyst library
@@ -99,7 +102,7 @@ class catalyst(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.ldconfig,
     default is empty.
 
     version: The version of Catalyst source to download.  The default
-    value is `5.6.0`.
+    value is `5.6.1`.
 
     # Examples
 
@@ -121,12 +124,10 @@ class catalyst(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.ldconfig,
         self.__runtime_ospackages = [] # Filled in by __distro()
         # Input toolchain, i.e., what to use when building
         self.__toolchain = kwargs.get('toolchain', toolchain())
-        self.__version = kwargs.get('version', '5.6.0')
+        self.__version = kwargs.get('version', '5.6.1')
         self.__url = r'https://www.paraview.org/paraview-downloads/download.php?submit=Download\&version={0}\&type=catalyst\&os=Sources\&downloadFile={1}'
 
         self.__commands = [] # Filled in by __setup()
-        self.__environment_variables = {
-            'PATH': '{}:$PATH'.format(posixpath.join(self.prefix, 'bin'))}
         self.__wd = '/var/tmp' # working directory
 
         # Validate edition choice
@@ -158,8 +159,7 @@ class catalyst(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.ldconfig,
         self += comment('ParaView Catalyst version {}'.format(self.__version))
         self += packages(ospackages=self.__ospackages)
         self += shell(commands=self.__commands)
-        if self.__environment_variables:
-            self += environment(variables=self.__environment_variables)
+        self += environment(variables=self.environment_step())
 
     def __distro(self):
         """Based on the Linux distribution, set values accordingly.  A user
@@ -235,13 +235,17 @@ class catalyst(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.ldconfig,
         if self.ldconfig:
             self.__commands.append(self.ldcache_step(directory=libpath))
         else:
-            self.__environment_variables['LD_LIBRARY_PATH'] = '{}:$LD_LIBRARY_PATH'.format(libpath)
+            self.environment_variables['LD_LIBRARY_PATH'] = '{}:$LD_LIBRARY_PATH'.format(libpath)
 
         # Cleanup
         self.__commands.append(self.cleanup_step(
             items=[posixpath.join(self.__wd, tarball),
                    posixpath.join(self.__wd, self.__basename)]))
 
+        # Set the environment
+        self.environment_variables['PATH'] = '{}:$PATH'.format(
+            posixpath.join(self.prefix, 'bin'))
+
     def runtime(self, _from='0'):
         """Generate the set of instructions to install the runtime specific
         components from a build in a previous stage.
@@ -263,7 +267,5 @@ class catalyst(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.ldconfig,
             instructions.append(shell(
                 commands=[self.ldcache_step(
                     directory=posixpath.join(self.prefix, 'lib'))]))
-        if self.__environment_variables:
-            instructions.append(environment(
-                variables=self.__environment_variables))
+        instructions.append(environment(variables=self.environment_step()))
         return '\n'.join(str(x) for x in instructions)
