@@ -55,6 +55,10 @@ class generic_autotools(bb_base, hpccm.templates.ConfigureMake,
     check: Boolean flag to specify whether the `make check` step
     should be performed.  The default is False.
 
+    commit: The git commit to clone.  Only recognized if the
+    `repository` parameter is specified.  The default is empty, i.e.,
+    use the latest commit on the default branch for the repository.
+
     configure_opts: List of options to pass to `configure`.  The
     default value is an empty list.
 
@@ -80,6 +84,9 @@ class generic_autotools(bb_base, hpccm.templates.ConfigureMake,
     `/usr/local`. It is highly recommended not use use this default
     and instead set the prefix to a package specific directory.
 
+    recursive: Initialize and checkout git submodules. `repository` parameter
+    must be specified. The default is False.
+
     repository: The git repository of the package to build.  One of
     this paramter or the `url` parameter must be specified.
 
@@ -114,6 +121,7 @@ class generic_autotools(bb_base, hpccm.templates.ConfigureMake,
         self.__branch = kwargs.get('branch', None)
         self.__build_directory = kwargs.get('build_directory', None)
         self.__check = kwargs.get('check', False)
+        self.__commit = kwargs.get('commit', None)
         self.configure_opts = kwargs.get('configure_opts', [])
         self.__directory = kwargs.get('directory', None)
         self.__environment = kwargs.get('environment', {})
@@ -121,6 +129,7 @@ class generic_autotools(bb_base, hpccm.templates.ConfigureMake,
         self.__make = kwargs.get('make', True)
         self.__postinstall = kwargs.get('postinstall', [])
         self.__preconfigure = kwargs.get('preconfigure', [])
+        self.__recursive = kwargs.get('recursive', False)
         self.__repository = kwargs.get('repository', None)
         self.__toolchain = kwargs.get('toolchain', toolchain())
         self.__url = kwargs.get('url', None)
@@ -134,6 +143,9 @@ class generic_autotools(bb_base, hpccm.templates.ConfigureMake,
         if self.__repository and self.__url:
             raise RuntimeError('cannot specify both a repository and a URL')
 
+        if self.__branch and self.__commit:
+            raise RuntimeError('cannot specify both a branch and a commit')
+
         # Construct the series of steps to execute
         self.__setup()
 
@@ -185,8 +197,8 @@ class generic_autotools(bb_base, hpccm.templates.ConfigureMake,
         if self.__repository:
             # Clone git repository
             self.__commands.append(self.clone_step(
-                branch=self.__branch, path=self.__wd,
-                repository=self.__repository))
+                branch=self.__branch, commit=self.__commit, path=self.__wd,
+                recursive=self.__recursive, repository=self.__repository))
 
             directory = posixpath.join(self.__wd, posixpath.splitext(
                 posixpath.basename(self.__repository))[0])
@@ -257,3 +269,5 @@ class generic_autotools(bb_base, hpccm.templates.ConfigureMake,
             instructions.append(copy(_from=_from, src=self.prefix,
                                      dest=self.prefix))
             return '\n'.join(str(x) for x in instructions)
+        else:
+            return
