@@ -58,6 +58,10 @@ class generic_cmake(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.git,
     cmake_opts: List of options to pass to `cmake`.  The default value
     is an empty list.
 
+    commit: The git commit to clone.  Only recognized if the
+    `repository` parameter is specified.  The default is empty, i.e.,
+    use the latest commit on the default branch for the repository.
+
     directory: The source code location.  The default value is the
     basename of the downloaded package.  If the value is not an
     absolute path, then the temporary working directory is prepended.
@@ -80,6 +84,9 @@ class generic_cmake(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.git,
     `/usr/local`. It is highly recommended not to use this default and
     instead set the prefix to a package specific directory.
 
+    recursive: Initialize and checkout git submodules. `repository` parameter
+    must be specified. The default is False.
+
     repository: The git repository of the package to build.  One of
     this paramter or the `url` parameter must be specified.
 
@@ -137,12 +144,14 @@ class generic_cmake(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.git,
         self.__build_directory = kwargs.get('build_directory', 'build')
         self.__check = kwargs.get('check', False)
         self.cmake_opts = kwargs.get('cmake_opts', [])
+        self.__commit = kwargs.get('commit', None)
         self.__directory = kwargs.get('directory', None)
         self.__environment = kwargs.get('environment', {})
         self.__install = kwargs.get('install', True)
         self.__make = kwargs.get('make', True)
         self.__postinstall = kwargs.get('postinstall', [])
         self.__preconfigure = kwargs.get('preconfigure', [])
+        self.__recursive = kwargs.get('recursive', False)
         self.__repository = kwargs.get('repository', None)
         self.__toolchain = kwargs.get('toolchain', toolchain())
         self.__url = kwargs.get('url', None)
@@ -156,6 +165,9 @@ class generic_cmake(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.git,
         if self.__repository and self.__url:
             raise RuntimeError('cannot specify both a repository and a URL')
 
+        if self.__branch and self.__commit:
+            raise RuntimeError('cannot specify both a branch and a commit')
+
         # Construct the series of steps to execute
         self.__setup()
 
@@ -207,8 +219,8 @@ class generic_cmake(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.git,
         if self.__repository:
             # Clone git repository
             self.__commands.append(self.clone_step(
-                branch=self.__branch, path=self.__wd,
-                repository=self.__repository))
+                branch=self.__branch, commit=self.__commit, path=self.__wd,
+                recursive=self.__recursive, repository=self.__repository))
 
             directory = posixpath.join(self.__wd, posixpath.splitext(
                 posixpath.basename(self.__repository))[0])
@@ -279,3 +291,5 @@ class generic_cmake(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.git,
             instructions.append(copy(_from=_from, src=self.prefix,
                                      dest=self.prefix))
             return '\n'.join(str(x) for x in instructions)
+        else:
+            return
