@@ -21,11 +21,13 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 from __future__ import print_function
 
+from distutils.version import LooseVersion
 import logging # pylint: disable=unused-import
 import posixpath
 
 import hpccm.config
 import hpccm.templates.ConfigureMake
+import hpccm.templates.envvars
 import hpccm.templates.ldconfig
 import hpccm.templates.rm
 import hpccm.templates.tar
@@ -40,16 +42,14 @@ from hpccm.primitives.environment import environment
 from hpccm.primitives.shell import shell
 from hpccm.toolchain import toolchain
 
-class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
-              hpccm.templates.rm, hpccm.templates.tar, hpccm.templates.wget):
+class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
+              hpccm.templates.ldconfig, hpccm.templates.rm,
+              hpccm.templates.tar, hpccm.templates.wget):
     """The `pnetcdf` building block downloads, configures, builds, and
     installs the
     [PnetCDF](http://cucis.ece.northwestern.edu/projects/PnetCDF/index.html)
     component.
 
-    As a side effect, this building block modifies `PATH` to include
-    the PnetCDF build.
-
     # Parameters
 
     check: Boolean flag to specify whether the `make check` step
@@ -58,6 +58,10 @@ class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
     configure_opts: List of options to pass to `configure`.  The
     default values are `--enable-shared`.
 
+    environment: Boolean flag to specify whether the environment
+    (`LD_LIBRARY_PATH` and `PATH`) should be modified to include
+    PnetCDF. The default is True.
+
     ldconfig: Boolean flag to specify whether the PnetCDF library
     directory should be added dynamic linker cache.  If False, then
     `LD_LIBRARY_PATH` is modified to include the PnetCDF library
@@ -75,7 +79,7 @@ class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
     e.g., `CC=mpicc`, `CXX=mpicxx`, etc.
 
     version: The version of PnetCDF source to download.  The default
-    value is `1.10.0`.
+    value is `1.11.2`.
 
     # Examples
 
@@ -87,6 +91,7 @@ class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
     ompi = openmpi(...)
     pnetcdf(toolchain=ompi.toolchain, ...)
     ```
+
     """
 
     def __init__(self, **kwargs):
@@ -97,7 +102,7 @@ class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
         self.configure_opts = kwargs.get('configure_opts', ['--enable-shared'])
         self.prefix = kwargs.get('prefix', '/usr/local/pnetcdf')
 
-        self.__baseurl = kwargs.get('baseurl', 'http://cucis.ece.northwestern.edu/projects/PnetCDF/Release')
+        self.__baseurl = kwargs.get('baseurl', 'https://parallel-netcdf.github.io/Release')
         self.__check = kwargs.get('check', False)
         self.__ospackages = kwargs.get('ospackages', ['m4', 'make', 'tar',
                                                       'wget'])
@@ -106,11 +111,9 @@ class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
                                       toolchain(CC='mpicc', CXX='mpicxx',
                                                 F77='mpif77', F90='mpif90',
                                                 FC='mpifort'))
-        self.__version = kwargs.get('version', '1.10.0')
+        self.__version = kwargs.get('version', '1.11.2')
 
         self.__commands = [] # Filled in by __setup()
-        self.__environment_variables = {
-            'PATH': '{}:$PATH'.format(posixpath.join(self.prefix, 'bin'))}
         self.__wd = '/var/tmp' # working directory
 
         # Set the Linux distribution specific parameters
@@ -128,8 +131,7 @@ class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
         self += comment('PnetCDF version {}'.format(self.__version))
         self += packages(ospackages=self.__ospackages)
         self += shell(commands=self.__commands)
-        if self.__environment_variables:
-            self += environment(variables=self.__environment_variables)
+        self += environment(variables=self.environment_step())
 
     def __distro(self):
         """Based on the Linux distribution, set values accordingly.  A user
@@ -146,7 +148,12 @@ class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
         """Construct the series of shell commands, i.e., fill in
            self.__commands"""
 
-        tarball = 'parallel-netcdf-{}.tar.gz'.format(self.__version)
+        # Version 1.11.0 changed the package name
+        if LooseVersion(self.__version) >= LooseVersion('1.11.0'):
+            pkgname = 'pnetcdf'
+        else:
+            pkgname = 'parallel-netcdf'
+        tarball = '{0}-{1}.tar.gz'.format(pkgname, self.__version)
         url = '{0}/{1}'.format(self.__baseurl, tarball)
 
         # Download source from web
@@ -155,8 +162,8 @@ class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
         self.__commands.append(self.untar_step(
             tarball=posixpath.join(self.__wd, tarball), directory=self.__wd))
         self.__commands.append(self.configure_step(
-            directory=posixpath.join(self.__wd, 'parallel-netcdf-{}'.format(
-                self.__version)),
+            directory=posixpath.join(self.__wd, '{0}-{1}'.format(
+                pkgname, self.__version)),
             toolchain=self.__toolchain))
 
         # For some compilers, --enable-shared leads to the following error:
@@ -165,7 +172,7 @@ class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
         # .libs/libpnetcdf.lax/libf77.a/strerrnof.o: error adding symbols: Bad value
         # Apply the workaround
         if '--enable-shared' in self.configure_opts:
-          self.__commands.append('sed -i -e \'s#pic_flag=""#pic_flag=" -fpic -DPIC"#\' -e \'s#wl=""#wl="-Wl,"#\' {}'.format(posixpath.join(self.__wd, 'parallel-netcdf-{}'.format(self.__version), 'libtool')))
+          self.__commands.append('sed -i -e \'s#pic_flag=""#pic_flag=" -fpic -DPIC"#\' -e \'s#wl=""#wl="-Wl,"#\' {}'.format(posixpath.join(self.__wd, '{0}-{1}'.format(pkgname, self.__version), 'libtool')))
 
         self.__commands.append(self.build_step())
 
@@ -180,13 +187,17 @@ class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
         if self.ldconfig:
             self.__commands.append(self.ldcache_step(directory=libpath))
         else:
-            self.__environment_variables['LD_LIBRARY_PATH'] = '{}:$LD_LIBRARY_PATH'.format(libpath)
+            self.environment_variables['LD_LIBRARY_PATH'] = '{}:$LD_LIBRARY_PATH'.format(libpath)
 
         # Cleanup tarball and directory
         self.__commands.append(self.cleanup_step(
             items=[posixpath.join(self.__wd, tarball),
                    posixpath.join(self.__wd,
-                                  'parallel-netcdf-{}'.format(self.__version))]))
+                                  '{0}-{1}'.format(pkgname, self.__version))]))
+
+        # Set the environment
+        self.environment_variables['PATH'] = '{}:$PATH'.format(
+            posixpath.join(self.prefix, 'bin'))
 
     def runtime(self, _from='0'):
         """Generate the set of instructions to install the runtime specific
@@ -210,7 +221,5 @@ class pnetcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.ldconfig,
             instructions.append(shell(
                 commands=[self.ldcache_step(
                     directory=posixpath.join(self.prefix, 'lib'))]))
-        if self.__environment_variables:
-            instructions.append(environment(
-                variables=self.__environment_variables))
+        instructions.append(environment(variables=self.environment_step()))
         return '\n'.join(str(x) for x in instructions)
